@@ -50,13 +50,12 @@ void ErrorTest::init()
 {
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
     m_display->createShm();
-    m_ci = m_display->createCompositor(m_display);
-    m_psi = m_display->createPlasmaShell(m_display);
-    m_psi->create();
+    m_ci = new CompositorInterface(m_display, m_display);
+    m_psi = new PlasmaShellInterface(m_display, m_display);
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
@@ -113,10 +112,11 @@ void ErrorTest::cleanup()
         delete m_thread;
         m_thread = nullptr;
     }
-    CLEANUP(m_psi)
-    CLEANUP(m_ci)
     CLEANUP(m_display)
 #undef CLEANUP
+    // these are the children of the display
+    m_psi = nullptr;
+    m_ci = nullptr;
 }
 
 void ErrorTest::testMultiplePlasmaShellSurfacesForSurface()
