@@ -63,16 +63,15 @@ void SelectionTest::init()
 {
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
     m_display->createShm();
-    m_compositorInterface = m_display->createCompositor(m_display);
-    m_seatInterface = m_display->createSeat(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
+    m_seatInterface = new SeatInterface(m_display, m_display);
     m_seatInterface->setHasKeyboard(true);
     m_seatInterface->create();
-    m_ddmInterface = m_display->createDataDeviceManager(m_display);
-    m_ddmInterface->create();
+    m_ddmInterface = new DataDeviceManagerInterface(m_display, m_display);
 
     // setup connection
     setupConnection(&m_client1);
@@ -163,11 +162,12 @@ void SelectionTest::cleanup()
         delete variable; \
         variable = nullptr;
 
-    CLEANUP(m_ddmInterface)
-    CLEANUP(m_seatInterface)
-    CLEANUP(m_compositorInterface)
     CLEANUP(m_display)
 #undef CLEANUP
+    // these are the children of the display
+    m_ddmInterface = nullptr;
+    m_seatInterface = nullptr;
+    m_compositorInterface = nullptr;
 }
 
 void SelectionTest::cleanupConnection(Connection *c)
