@@ -52,12 +52,12 @@ void ShadowTest::init()
 {
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
     m_display->createShm();
-    m_compositorInterface = m_display->createCompositor(m_display);
-    m_shadowInterface = m_display->createShadowManager(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
+    m_shadowInterface = new ShadowManagerInterface(m_display, m_display);
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
@@ -120,10 +120,12 @@ void ShadowTest::cleanup()
         m_thread = nullptr;
     }
 
-    CLEANUP(m_compositorInterface)
-    CLEANUP(m_shadowInterface)
     CLEANUP(m_display)
 #undef CLEANUP
+
+    // these are the children of the display
+    m_compositorInterface = nullptr;
+    m_shadowInterface = nullptr;
 }
 
 void ShadowTest::testCreateShadow()
