@@ -77,12 +77,12 @@ void TestFilter::init()
     using namespace KWaylandServer;
     delete m_display;
     m_display = new TestDisplay(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
 
-    m_compositorInterface = m_display->createCompositor(m_display);
-    m_blurManagerInterface = m_display->createBlurManager(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
+    m_blurManagerInterface = new BlurManagerInterface(m_display, m_display);
 }
 
 void TestFilter::cleanup()
