@@ -91,12 +91,12 @@ void TestWaylandOutputManagement::init()
     using namespace KWaylandServer;
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
 
-    m_display->createCompositor(this);
-    auto outputDeviceInterface = m_display->createOutputDevice(this);
+    new CompositorInterface(m_display, this);
+    auto outputDeviceInterface = new OutputDeviceInterface(m_display, this);
 
     OutputDeviceInterface::Mode m0;
     m0.id = 0;
@@ -129,7 +129,7 @@ void TestWaylandOutputManagement::init()
     outputDeviceInterface->create();
     m_serverOutputs << outputDeviceInterface;
 
-    m_outputManagementInterface = m_display->createOutputManagement(this);
+    m_outputManagementInterface = new OutputManagementInterface(m_display, this);
     m_outputManagementInterface->create();
     QVERIFY(m_outputManagementInterface->isValid());
 
@@ -200,14 +200,13 @@ void TestWaylandOutputManagement::cleanup()
         m_thread = nullptr;
     }
 
-    if (m_outputManagementInterface) {
-        delete m_outputManagementInterface;
-        m_outputManagementInterface = nullptr;
-    }
     delete m_display;
     m_display = nullptr;
     m_serverOutputs.clear();
     m_clientOutputs.clear();
+
+    // these are the children of the display
+    m_outputManagementInterface = nullptr;
 }
 
 void TestWaylandOutputManagement::applyPendingChanges(KWaylandServer::OutputConfigurationInterface *configurationInterface)
