@@ -61,7 +61,7 @@ void TestSlide::init()
     using namespace KWaylandServer;
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
 
@@ -96,13 +96,11 @@ void TestSlide::init()
     QVERIFY(registry.isValid());
     registry.setup();
 
-    m_compositorInterface = m_display->createCompositor(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
     QVERIFY(compositorSpy.wait());
     m_compositor = registry.createCompositor(compositorSpy.first().first().value<quint32>(), compositorSpy.first().last().value<quint32>(), this);
 
-    m_slideManagerInterface = m_display->createSlideManager(m_display);
-    m_slideManagerInterface->create();
-    QVERIFY(m_slideManagerInterface->isValid());
+    m_slideManagerInterface = new SlideManagerInterface(m_display, m_display);
 
     QVERIFY(slideSpy.wait());
     m_slideManager = registry.createSlideManager(slideSpy.first().first().value<quint32>(), slideSpy.first().last().value<quint32>(), this);
@@ -128,10 +126,12 @@ void TestSlide::cleanup()
         delete m_thread;
         m_thread = nullptr;
     }
-    CLEANUP(m_compositorInterface)
-    CLEANUP(m_slideManagerInterface)
     CLEANUP(m_display)
 #undef CLEANUP
+    // these are the children of the display
+    m_compositorInterface = nullptr;
+    m_slideManagerInterface = nullptr;
+
 }
 
 void TestSlide::testCreate()
