@@ -82,7 +82,7 @@ void TestForeign::init()
     using namespace KWaylandServer;
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
 
@@ -122,11 +122,11 @@ void TestForeign::init()
     QVERIFY(registry.isValid());
     registry.setup();
 
-    m_compositorInterface = m_display->createCompositor(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
     QVERIFY(compositorSpy.wait());
     m_compositor = registry.createCompositor(compositorSpy.first().first().value<quint32>(), compositorSpy.first().last().value<quint32>(), this);
 
-    m_foreignInterface = m_display->createXdgForeignV2Interface(m_display);
+    m_foreignInterface = new XdgForeignV2Interface(m_display, m_display);
 
     QVERIFY(exporterSpy.wait());
     //Both importer and exporter should have been triggered by now
@@ -159,11 +159,12 @@ void TestForeign::cleanup()
         delete m_thread;
         m_thread = nullptr;
     }
-    CLEANUP(m_foreignInterface)
     delete m_display;
     m_display = nullptr;
-
 #undef CLEANUP
+
+    // these are the children of the display
+    m_foreignInterface = nullptr;
 }
 
 void TestForeign::doExport()
