@@ -35,17 +35,16 @@ private Q_SLOTS:
 void TestWaylandServerDisplay::testSocketName()
 {
     Display display;
-    QSignalSpy changedSpy(&display, SIGNAL(socketNameChanged(QString)));
+    QSignalSpy changedSpy(&display, &Display::socketNamesChanged);
     QVERIFY(changedSpy.isValid());
-    QCOMPARE(display.socketName(), QStringLiteral("wayland-0"));
+    QCOMPARE(display.socketNames(), QStringList());
     const QString testSName = QStringLiteral("fooBar");
-    display.setSocketName(testSName);
-    QCOMPARE(display.socketName(), testSName);
+    display.addSocketName(testSName);
+    QCOMPARE(display.socketNames(), QStringList { testSName });
     QCOMPARE(changedSpy.count(), 1);
-    QCOMPARE(changedSpy.first().first().toString(), testSName);
 
     // changing to same name again should not emit signal
-    display.setSocketName(testSName);
+    display.addSocketName(testSName);
     QCOMPARE(changedSpy.count(), 1);
 }
 
@@ -59,7 +58,7 @@ void TestWaylandServerDisplay::testStartStop()
     QScopedPointer<Display> display(new Display);
     QSignalSpy runningSpy(display.data(), SIGNAL(runningChanged(bool)));
     QVERIFY(runningSpy.isValid());
-    display->setSocketName(testSocketName);
+    display->addSocketName(testSocketName);
     QVERIFY(!display->isRunning());
     display->start();
 //     QVERIFY(runningSpy.wait());
@@ -75,30 +74,21 @@ void TestWaylandServerDisplay::testStartStop()
 void TestWaylandServerDisplay::testAddRemoveOutput()
 {
     Display display;
-    display.setSocketName(QStringLiteral("kwin-wayland-server-display-test-output-0"));
+    display.addSocketName(QStringLiteral("kwin-wayland-server-display-test-output-0"));
     display.start();
 
-    OutputInterface *output = display.createOutput();
+    OutputInterface *output = new OutputInterface(&display);
     QCOMPARE(display.outputs().size(), 1);
     QCOMPARE(display.outputs().first(), output);
-    // create a second output
-    OutputInterface *output2 = display.createOutput();
-    QCOMPARE(display.outputs().size(), 2);
-    QCOMPARE(display.outputs().first(), output);
-    QCOMPARE(display.outputs().last(), output2);
-    // remove the first output
-    display.removeOutput(output);
-    QCOMPARE(display.outputs().size(), 1);
-    QCOMPARE(display.outputs().first(), output2);
-    // and delete the second
-    delete output2;
+
+    delete output;
     QVERIFY(display.outputs().isEmpty());
 }
 
 void TestWaylandServerDisplay::testClientConnection()
 {
     Display display;
-    display.setSocketName(QStringLiteral("kwin-wayland-server-display-test-client-connection"));
+    display.addSocketName(QStringLiteral("kwin-wayland-server-display-test-client-connection"));
     display.start();
     QSignalSpy connectedSpy(&display, SIGNAL(clientConnected(KWaylandServer::ClientConnection*)));
     QVERIFY(connectedSpy.isValid());
@@ -174,7 +164,7 @@ void TestWaylandServerDisplay::testClientConnection()
 void TestWaylandServerDisplay::testConnectNoSocket()
 {
     Display display;
-    display.start(Display::StartMode::ConnectClientsOnly);
+    display.start();
     QVERIFY(display.isRunning());
 
     // let's try connecting a client
@@ -191,9 +181,9 @@ void TestWaylandServerDisplay::testConnectNoSocket()
 void TestWaylandServerDisplay::testOutputManagement()
 {
     Display display;
-    display.setSocketName("kwayland-test-0");
+    display.addSocketName("kwayland-test-0");
     display.start();
-    auto kwin = display.createOutputManagement(this);
+    auto kwin = new OutputManagementInterface(&display, this);
     kwin->create();
     QVERIFY(kwin->isValid());
 }
@@ -205,20 +195,20 @@ void TestWaylandServerDisplay::testAutoSocketName()
     QVERIFY(qputenv("XDG_RUNTIME_DIR", runtimeDir.path().toUtf8()));
 
     Display display0;
-    display0.setAutomaticSocketNaming(true);
-    QSignalSpy socketNameChangedSpy0(&display0, SIGNAL(socketNameChanged(QString)));
+    QSignalSpy socketNameChangedSpy0(&display0, &Display::socketNamesChanged);
+    QVERIFY(socketNameChangedSpy0.isValid());
+    QVERIFY(display0.addSocketName());
     display0.start();
     QVERIFY(display0.isRunning());
-    QCOMPARE(socketNameChangedSpy0.count(), 0);
-    QCOMPARE(display0.socketName(), QStringLiteral("wayland-0"));
+    QCOMPARE(socketNameChangedSpy0.count(), 1);
 
     Display display1;
-    display1.setAutomaticSocketNaming(true);
-    QSignalSpy socketNameChangedSpy1(&display1, SIGNAL(socketNameChanged(QString)));
+    QSignalSpy socketNameChangedSpy1(&display1, &Display::socketNamesChanged);
+    QVERIFY(socketNameChangedSpy1.isValid());
+    QVERIFY(display1.addSocketName());
     display1.start();
     QVERIFY(display1.isRunning());
     QCOMPARE(socketNameChangedSpy1.count(), 1);
-    QCOMPARE(display1.socketName(), QStringLiteral("wayland-1"));
 }
 
 
