@@ -4,6 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "outputdevice_interface.h"
+#include "display_p.h"
 #include "global_p.h"
 #include "display.h"
 #include "logging.h"
@@ -86,11 +87,19 @@ OutputDeviceInterface::Private::Private(OutputDeviceInterface *q, Display *d)
     : Global::Private(d, &org_kde_kwin_outputdevice_interface, s_version)
     , q(q)
 {
+    DisplayPrivate *displayPrivate = DisplayPrivate::get(display);
+    displayPrivate->outputdevices.append(q);
+
     s_privates << this;
 }
 
 OutputDeviceInterface::Private::~Private()
 {
+    if (display) {
+        DisplayPrivate *displayPrivate = DisplayPrivate::get(display);
+        displayPrivate->outputdevices.removeOne(q);
+    }
+
     s_privates.removeAll(this);
 }
 
@@ -133,8 +142,7 @@ OutputDeviceInterface::OutputDeviceInterface(Display *display, QObject *parent)
     connect(this, &OutputDeviceInterface::globalPositionChanged, this, [d] { d->updateGeometry(); });
     connect(this, &OutputDeviceInterface::modelChanged,          this, [d] { d->updateGeometry(); });
     connect(this, &OutputDeviceInterface::manufacturerChanged,   this, [d] { d->updateGeometry(); });
-    connect(this, &OutputDeviceInterface::scaleFChanged,          this, [d] { d->updateScale(); });
-    connect(this, &OutputDeviceInterface::scaleChanged,          this, [d] { d->updateScale(); });
+    connect(this, &OutputDeviceInterface::scaleFChanged,         this, [d] { d->updateScale(); });
     connect(this, &OutputDeviceInterface::colorCurvesChanged,    this, [d] { d->updateColorCurves(); });
 }
 
@@ -266,6 +274,21 @@ void OutputDeviceInterface::setCurrentMode(const int modeId)
     emit currentModeChanged();
 }
 
+bool OutputDeviceInterface::setCurrentMode(const QSize &size, int refreshRate)
+{
+    Q_D();
+    auto mode = std::find_if(d->modes.constBegin(), d->modes.constEnd(),
+        [size, refreshRate](const Mode &mode) {
+            return mode.size == size && mode.refreshRate == refreshRate;
+        }
+    );
+    if (mode == d->modes.constEnd()) {
+        return false;
+    }
+    setCurrentMode((*mode).id);
+    return true;
+}
+
 int32_t OutputDeviceInterface::Private::toTransform() const
 {
     switch (transform) {
