@@ -15,6 +15,8 @@
 namespace KWaylandServer
 {
 
+static const quint32 s_version = 1;
+
 class ServerSideDecorationManagerInterfacePrivate : public QtWaylandServer::org_kde_kwin_server_decoration_manager
 {
 public:
@@ -22,10 +24,7 @@ public:
     void setDefaultMode(ServerSideDecorationManagerInterface::Mode mode);
 
     ServerSideDecorationManagerInterface::Mode defaultMode = ServerSideDecorationManagerInterface::Mode::None;
-    
-private:
     ServerSideDecorationManagerInterface *q;
-    static const quint32 s_version;
 
 protected:
     void org_kde_kwin_server_decoration_manager_bind_resource(Resource *resource) override;
@@ -33,8 +32,6 @@ protected:
 
 };
 
-const quint32 ServerSideDecorationManagerInterfacePrivate::s_version = 1;
-
 static uint32_t modeWayland(ServerSideDecorationManagerInterface::Mode mode)
 {
     switch (mode) {
