@@ -11,11 +11,12 @@
 #include "compositor_interface.h"
 #include "display.h"
 #include "idleinhibit_v1_interface_p.h"
-#include "pointerconstraints_interface_p.h"
+#include "pointerconstraints_v1_interface_p.h"
 #include "region_interface.h"
 #include "subcompositor_interface.h"
 #include "subsurface_interface_p.h"
 #include "surfacerole_p.h"
+#include "utils.h"
 // std
 #include <algorithm>
 
@@ -76,21 +77,24 @@ SurfaceInterfacePrivate::~SurfaceInterfacePrivate()
     surfaces.removeOne(q);
 }
 
-void SurfaceInterfacePrivate::addChild(QPointer<SubSurfaceInterface> child)
+void SurfaceInterfacePrivate::addChild(SubSurfaceInterface *child)
 {
     // protocol is not precise on how to handle the addition of new sub surfaces
     pending.children.append(child);
     cached.children.append(child);
     current.children.append(child);
+
+    child->surface()->setOutputs(outputs);
+
     emit q->childSubSurfaceAdded(child);
     emit q->subSurfaceTreeChanged();
-    QObject::connect(child.data(), &SubSurfaceInterface::positionChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
-    QObject::connect(child->surface().data(), &SurfaceInterface::damaged, q, &SurfaceInterface::subSurfaceTreeChanged);
-    QObject::connect(child->surface().data(), &SurfaceInterface::unmapped, q, &SurfaceInterface::subSurfaceTreeChanged);
-    QObject::connect(child->surface().data(), &SurfaceInterface::subSurfaceTreeChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
+    QObject::connect(child, &SubSurfaceInterface::positionChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
+    QObject::connect(child->surface(), &SurfaceInterface::damaged, q, &SurfaceInterface::subSurfaceTreeChanged);
+    QObject::connect(child->surface(), &SurfaceInterface::unmapped, q, &SurfaceInterface::subSurfaceTreeChanged);
+    QObject::connect(child->surface(), &SurfaceInterface::subSurfaceTreeChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
 }
 
-void SurfaceInterfacePrivate::removeChild(QPointer<SubSurfaceInterface> child)
+void SurfaceInterfacePrivate::removeChild(SubSurfaceInterface *child)
 {
     // protocol is not precise on how to handle the addition of new sub surfaces
     pending.children.removeAll(child);
@@ -98,15 +102,15 @@ void SurfaceInterfacePrivate::removeChild(QPointer<SubSurfaceInterface> child)
     current.children.removeAll(child);
     emit q->childSubSurfaceRemoved(child);
     emit q->subSurfaceTreeChanged();
-    QObject::disconnect(child.data(), &SubSurfaceInterface::positionChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
-    if (!child->surface().isNull()) {
-        QObject::disconnect(child->surface().data(), &SurfaceInterface::damaged, q, &SurfaceInterface::subSurfaceTreeChanged);
-        QObject::disconnect(child->surface().data(), &SurfaceInterface::unmapped, q, &SurfaceInterface::subSurfaceTreeChanged);
-        QObject::disconnect(child->surface().data(), &SurfaceInterface::subSurfaceTreeChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
+    QObject::disconnect(child, &SubSurfaceInterface::positionChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
+    if (child->surface()) {
+        QObject::disconnect(child->surface(), &SurfaceInterface::damaged, q, &SurfaceInterface::subSurfaceTreeChanged);
+        QObject::disconnect(child->surface(), &SurfaceInterface::unmapped, q, &SurfaceInterface::subSurfaceTreeChanged);
+        QObject::disconnect(child->surface(), &SurfaceInterface::subSurfaceTreeChanged, q, &SurfaceInterface::subSurfaceTreeChanged);
     }
 }
 
-bool SurfaceInterfacePrivate::raiseChild(QPointer<SubSurfaceInterface> subsurface, SurfaceInterface *sibling)
+bool SurfaceInterfacePrivate::raiseChild(SubSurfaceInterface *subsurface, SurfaceInterface *sibling)
 {
     auto it = std::find(pending.children.begin(), pending.children.end(), subsurface);
     if (it == pending.children.end()) {
@@ -141,7 +145,7 @@ bool SurfaceInterfacePrivate::raiseChild(QPointer<SubSurfaceInterface> subsurfac
     return true;
 }
 
-bool SurfaceInterfacePrivate::lowerChild(QPointer<SubSurfaceInterface> subsurface, SurfaceInterface *sibling)
+bool SurfaceInterfacePrivate::lowerChild(SubSurfaceInterface *subsurface, SurfaceInterface *sibling)
 {
     auto it = std::find(pending.children.begin(), pending.children.end(), subsurface);
     if (it == pending.children.end()) {
@@ -201,14 +205,15 @@ void SurfaceInterfacePrivate::setContrast(const QPointer<ContrastInterface> &con
     pending.contrastIsSet = true;
 }
 
-void SurfaceInterfacePrivate::installPointerConstraint(LockedPointerInterface *lock)
+void SurfaceInterfacePrivate::installPointerConstraint(LockedPointerV1Interface *lock)
 {
-    Q_ASSERT(lockedPointer.isNull());
-    Q_ASSERT(confinedPointer.isNull());
-    lockedPointer = QPointer<LockedPointerInterface>(lock);
+    Q_ASSERT(!lockedPointer);
+    Q_ASSERT(!confinedPointer);
+
+    lockedPointer = lock;
 
     auto cleanUp = [this]() {
-        lockedPointer.clear();
+        lockedPointer = nullptr;
         QObject::disconnect(constrainsOneShotConnection);
         constrainsOneShotConnection = QMetaObject::Connection();
         QObject::disconnect(constrainsUnboundConnection);
@@ -216,35 +221,29 @@ void SurfaceInterfacePrivate::installPointerConstraint(LockedPointerInterface *l
         emit q->pointerConstraintsChanged();
     };
 
-    if (lock->lifeTime() == LockedPointerInterface::LifeTime::OneShot) {
-        constrainsOneShotConnection = QObject::connect(lock, &LockedPointerInterface::lockedChanged, q,
+    if (lock->lifeTime() == LockedPointerV1Interface::LifeTime::OneShot) {
+        constrainsOneShotConnection = QObject::connect(lock, &LockedPointerV1Interface::lockedChanged, q,
             [this, cleanUp] {
-                if (lockedPointer.isNull() || lockedPointer->isLocked()) {
+                if (lockedPointer->isLocked()) {
                     return;
                 }
                 cleanUp();
             }
         );
     }
-    constrainsUnboundConnection = QObject::connect(lock, &LockedPointerInterface::unbound, q,
-        [this, cleanUp] {
-            if (lockedPointer.isNull()) {
-                return;
-            }
-            cleanUp();
-        }
-    );
+    constrainsUnboundConnection = QObject::connect(lock, &LockedPointerV1Interface::destroyed, q, cleanUp);
     emit q->pointerConstraintsChanged();
 }
 
-void SurfaceInterfacePrivate::installPointerConstraint(ConfinedPointerInterface *confinement)
+void SurfaceInterfacePrivate::installPointerConstraint(ConfinedPointerV1Interface *confinement)
 {
-    Q_ASSERT(lockedPointer.isNull());
-    Q_ASSERT(confinedPointer.isNull());
-    confinedPointer = QPointer<ConfinedPointerInterface>(confinement);
+    Q_ASSERT(!lockedPointer);
+    Q_ASSERT(!confinedPointer);
+
+    confinedPointer = confinement;
 
     auto cleanUp = [this]() {
-        confinedPointer.clear();
+        confinedPointer = nullptr;
         QObject::disconnect(constrainsOneShotConnection);
         constrainsOneShotConnection = QMetaObject::Connection();
         QObject::disconnect(constrainsUnboundConnection);
@@ -252,24 +251,17 @@ void SurfaceInterfacePrivate::installPointerConstraint(ConfinedPointerInterface
         emit q->pointerConstraintsChanged();
     };
 
-    if (confinement->lifeTime() == ConfinedPointerInterface::LifeTime::OneShot) {
-        constrainsOneShotConnection = QObject::connect(confinement, &ConfinedPointerInterface::confinedChanged, q,
+    if (confinement->lifeTime() == ConfinedPointerV1Interface::LifeTime::OneShot) {
+        constrainsOneShotConnection = QObject::connect(confinement, &ConfinedPointerV1Interface::confinedChanged, q,
             [this, cleanUp] {
-                if (confinedPointer.isNull() || confinedPointer->isConfined()) {
+                if (confinedPointer->isConfined()) {
                     return;
                 }
                 cleanUp();
             }
         );
     }
-    constrainsUnboundConnection = QObject::connect(confinement, &ConfinedPointerInterface::unbound, q,
-        [this, cleanUp] {
-            if (confinedPointer.isNull()) {
-                return;
-            }
-            cleanUp();
-        }
-    );
+    constrainsUnboundConnection = QObject::connect(confinement, &ConfinedPointerV1Interface::destroyed, q, cleanUp);
     emit q->pointerConstraintsChanged();
 }
 
@@ -318,7 +310,7 @@ void SurfaceInterfacePrivate::surface_attach(Resource *resource, struct ::wl_res
 
 void SurfaceInterfacePrivate::surface_damage(Resource *, int32_t x, int32_t y, int32_t width, int32_t height)
 {
-    pending.damage = pending.damage.united(QRect(x, y, width, height));
+    pending.damage |= QRect(x, y, width, height);
 }
 
 void SurfaceInterfacePrivate::surface_frame(Resource *resource, uint32_t callback)
@@ -345,8 +337,7 @@ void SurfaceInterfacePrivate::surface_set_input_region(Resource *resource, struc
 {
     Q_UNUSED(resource)
     RegionInterface *r = RegionInterface::get(region);
-    pending.input = r ? r->region() : QRegion();
-    pending.inputIsInfinite = !r;
+    pending.input = r ? r->region() : infiniteRegion();
     pending.inputIsSet = true;
 }
 
@@ -373,7 +364,7 @@ void SurfaceInterfacePrivate::surface_set_buffer_scale(Resource *resource, int32
 void SurfaceInterfacePrivate::surface_damage_buffer(Resource *resource, int32_t x, int32_t y, int32_t width, int32_t height)
 {
     Q_UNUSED(resource)
-    pending.bufferDamage = pending.bufferDamage.united(QRect(x, y, width, height));
+    pending.bufferDamage |= QRect(x, y, width, height);
 }
 
 SurfaceInterface::SurfaceInterface(CompositorInterface *compositor, wl_resource *resource)
@@ -424,11 +415,7 @@ void SurfaceInterface::frameRendered(quint32 msec)
         frameCallback->destroy();
     }
     for (auto it = d->current.children.constBegin(); it != d->current.children.constEnd(); ++it) {
-        const auto &subSurface = *it;
-        if (subSurface.isNull() || subSurface->d_func()->surface.isNull()) {
-            continue;
-        }
-        subSurface->d_func()->surface->frameRendered(msec);
+        (*it)->surface()->frameRendered(msec);
     }
     if (needsFlush)  {
         client()->flush();
@@ -509,6 +496,7 @@ void SurfaceInterfacePrivate::swapStates(State *source, State *target, bool emit
     const QSize oldSize = target->size;
     const QSize oldBufferSize = bufferSize;
     const QMatrix4x4 oldSurfaceToBufferMatrix = surfaceToBufferMatrix;
+    const QRegion oldInputRegion = inputRegion;
     if (bufferChanged) {
         // TODO: is the reffing correct for subsurfaces?
         if (target->buffer) {
@@ -561,7 +549,6 @@ void SurfaceInterfacePrivate::swapStates(State *source, State *target, bool emit
     }
     if (inputRegionChanged) {
         target->input = source->input;
-        target->inputIsInfinite = source->inputIsInfinite;
         target->inputIsSet = true;
     }
     if (opaqueRegionChanged) {
@@ -576,11 +563,13 @@ void SurfaceInterfacePrivate::swapStates(State *source, State *target, bool emit
         target->bufferTransform = source->bufferTransform;
         target->bufferTransformIsSet = true;
     }
-    if (!lockedPointer.isNull()) {
-        lockedPointer->d_func()->commit();
+    if (lockedPointer) {
+        auto lockedPointerPrivate = LockedPointerV1InterfacePrivate::get(lockedPointer);
+        lockedPointerPrivate->commit();
     }
-    if (!confinedPointer.isNull()) {
-        confinedPointer->d_func()->commit();
+    if (confinedPointer) {
+        auto confinedPointerPrivate = ConfinedPointerV1InterfacePrivate::get(confinedPointer);
+        confinedPointerPrivate->commit();
     }
 
     *source = State{};
@@ -618,11 +607,12 @@ void SurfaceInterfacePrivate::swapStates(State *source, State *target, bool emit
     }
     surfaceToBufferMatrix = buildSurfaceToBufferMatrix(target);
     bufferToSurfaceMatrix = surfaceToBufferMatrix.inverted();
+    inputRegion = target->input & QRect(QPoint(0, 0), target->size);
     if (opaqueRegionChanged) {
         emit q->opaqueChanged(target->opaque);
     }
-    if (inputRegionChanged) {
-        emit q->inputChanged(target->input);
+    if (oldInputRegion != inputRegion) {
+        emit q->inputChanged(inputRegion);
     }
     if (scaleFactorChanged) {
         emit q->bufferScaleChanged(target->bufferScale);
@@ -644,7 +634,7 @@ void SurfaceInterfacePrivate::swapStates(State *source, State *target, bool emit
             const QRegion windowRegion = QRegion(0, 0, q->size().width(), q->size().height());
             const QRegion bufferDamage = q->mapFromBuffer(target->bufferDamage);
             target->damage = windowRegion.intersected(target->damage.united(bufferDamage));
-            trackedDamage = trackedDamage.united(target->damage);
+            trackedDamage |= target->damage;
             emit q->damaged(target->damage);
             // workaround for https://bugreports.qt.io/browse/QTBUG-52092
             // if the surface is a sub-surface, but the main surface is not yet mapped, fake frame rendered
@@ -684,43 +674,22 @@ void SurfaceInterfacePrivate::swapStates(State *source, State *target, bool emit
 
 void SurfaceInterfacePrivate::commit()
 {
-    if (!subSurface.isNull() && subSurface->isSynchronized()) {
-        swapStates(&pending, &cached, false);
-    } else {
+    if (!subSurface) {
         swapStates(&pending, &current, true);
-        if (!subSurface.isNull()) {
-            subSurface->d_func()->commit();
-        }
-        // commit all subSurfaces to apply position changes
-        // "The cached state is applied to the sub-surface immediately after the parent surface's state is applied"
-        for (auto it = current.children.constBegin(); it != current.children.constEnd(); ++it) {
-            const auto &subSurface = *it;
-            if (subSurface.isNull()) {
-                continue;
-            }
-            subSurface->d_func()->commit();
+
+        // The position of a sub-surface is applied when its parent is committed.
+        const QList<SubSurfaceInterface *> children = current.children;
+        for (SubSurfaceInterface *subsurface : children) {
+            auto subsurfacePrivate = SubSurfaceInterfacePrivate::get(subsurface);
+            subsurfacePrivate->parentCommit();
         }
     }
+
     if (role) {
         role->commit();
     }
-    emit q->committed();
-}
 
-void SurfaceInterfacePrivate::commitSubSurface()
-{
-    if (subSurface.isNull() || !subSurface->isSynchronized()) {
-        return;
-    }
-    swapStates(&cached, &current, true);
-    // "The cached state is applied to the sub-surface immediately after the parent surface's state is applied"
-    for (auto it = current.children.constBegin(); it != current.children.constEnd(); ++it) {
-        const auto &subSurface = *it;
-        if (subSurface.isNull() || !subSurface->isSynchronized()) {
-            continue;
-        }
-        subSurface->d_func()->commit();
-    }
+    emit q->committed();
 }
 
 QRegion SurfaceInterface::damage() const
@@ -735,12 +704,7 @@ QRegion SurfaceInterface::opaque() const
 
 QRegion SurfaceInterface::input() const
 {
-    return d->current.input;
-}
-
-bool SurfaceInterface::inputIsInfinite() const
-{
-    return d->current.inputIsInfinite;
+    return d->inputRegion;
 }
 
 qint32 SurfaceInterface::bufferScale() const
@@ -765,8 +729,8 @@ QPoint SurfaceInterface::offset() const
 
 SurfaceInterface *SurfaceInterface::get(wl_resource *native)
 {
-    if (auto surface = SurfaceInterfacePrivate::Resource::fromResource(native)) {
-        return static_cast<SurfaceInterfacePrivate *>(surface->object())->q;
+    if (auto surfacePrivate = resource_cast<SurfaceInterfacePrivate *>(native)) {
+        return surfacePrivate->q;
     }
     return nullptr;
 }
@@ -782,12 +746,12 @@ SurfaceInterface *SurfaceInterface::get(quint32 id, const ClientConnection *clie
     return nullptr;
 }
 
-QList< QPointer< SubSurfaceInterface > > SurfaceInterface::childSubSurfaces() const
+QList<SubSurfaceInterface *> SurfaceInterface::childSubSurfaces() const
 {
     return d->current.children;
 }
 
-QPointer< SubSurfaceInterface > SurfaceInterface::subSurface() const
+SubSurfaceInterface *SurfaceInterface::subSurface() const
 {
     return d->subSurface;
 }
@@ -801,7 +765,7 @@ QRect SurfaceInterface::boundingRect() const
 {
     QRect rect(QPoint(0, 0), size());
 
-    const QList<QPointer<SubSurfaceInterface>> subSurfaces = childSubSurfaces();
+    const QList<SubSurfaceInterface *> subSurfaces = childSubSurfaces();
     for (const SubSurfaceInterface *subSurface : subSurfaces) {
         const SurfaceInterface *childSurface = subSurface->surface();
         rect |= childSurface->boundingRect().translated(subSurface->position());
@@ -835,7 +799,7 @@ bool SurfaceInterface::isMapped() const
     if (d->subSurface) {
         // from spec:
         // "A sub-surface becomes mapped, when a non-NULL wl_buffer is applied and the parent surface is mapped."
-        return d->subSurfaceIsMapped && !d->subSurface->parentSurface().isNull() && d->subSurface->parentSurface()->isMapped();
+        return d->subSurfaceIsMapped && d->subSurface->parentSurface() && d->subSurface->parentSurface()->isMapped();
     }
     return d->current.buffer != nullptr;
 }
@@ -868,6 +832,7 @@ void SurfaceInterface::setOutputs(const QVector<OutputInterface *> &outputs)
             d->send_leave(outputResource);
         }
         disconnect(d->outputDestroyedConnections.take(*it));
+        disconnect(d->outputBoundConnections.take(*it));
     }
     QVector<OutputInterface *> addedOutputsOutputs = outputs;
     for (auto it = d->outputs.constBegin(), end = d->outputs.constEnd(); it != end; ++it) {
@@ -885,10 +850,20 @@ void SurfaceInterface::setOutputs(const QVector<OutputInterface *> &outputs)
             if (outputs.removeOne(o)) {
                 setOutputs(outputs);
             }});
+
+        Q_ASSERT(!d->outputBoundConnections.contains(o));
+        d->outputBoundConnections[o] = connect(o, &OutputInterface::bound, this, [this](ClientConnection *c, wl_resource *outputResource) {
+            if (c != client()) {
+                return;
+            }
+            d->send_enter(outputResource);
+        });
     }
-    // TODO: send enter when the client binds the OutputInterface another time
 
     d->outputs = outputs;
+    for (auto child : d->current.children) {
+        child->surface()->setOutputs(outputs);
+    }
 }
 
 SurfaceInterface *SurfaceInterface::surfaceAt(const QPointF &position)
@@ -897,14 +872,11 @@ SurfaceInterface *SurfaceInterface::surfaceAt(const QPointF &position)
         return nullptr;
     }
     // go from top to bottom. Top most child is last in list
-    QListIterator<QPointer<SubSurfaceInterface>> it(d->current.children);
+    QListIterator<SubSurfaceInterface *> it(d->current.children);
     it.toBack();
     while (it.hasPrevious()) {
         const auto &current = it.previous();
         auto surface = current->surface();
-        if (surface.isNull()) {
-            continue;
-        }
         if (auto s = surface->surfaceAt(position - current->position())) {
             return s;
         }
@@ -924,32 +896,29 @@ SurfaceInterface *SurfaceInterface::inputSurfaceAt(const QPointF &position)
         return nullptr;
     }
     // go from top to bottom. Top most child is last in list
-    QListIterator<QPointer<SubSurfaceInterface>> it(d->current.children);
+    QListIterator<SubSurfaceInterface *> it(d->current.children);
     it.toBack();
     while (it.hasPrevious()) {
         const auto &current = it.previous();
         auto surface = current->surface();
-        if (surface.isNull()) {
-            continue;
-        }
         if (auto s = surface->inputSurfaceAt(position - current->position())) {
             return s;
         }
     }
     // check whether the geometry and input region contain the pos
     if (!size().isEmpty() && QRectF(QPoint(0, 0), size()).contains(position) &&
-            (inputIsInfinite() || input().contains(position.toPoint()))) {
+            input().contains(position.toPoint())) {
         return this;
     }
     return nullptr;
 }
 
-QPointer<LockedPointerInterface> SurfaceInterface::lockedPointer() const
+LockedPointerV1Interface *SurfaceInterface::lockedPointer() const
 {
     return d->lockedPointer;
 }
 
-QPointer<ConfinedPointerInterface> SurfaceInterface::confinedPointer() const
+ConfinedPointerV1Interface *SurfaceInterface::confinedPointer() const
 {
     return d->confinedPointer;
 }
