@@ -20,10 +20,10 @@ namespace KWaylandServer
 {
 class BlurInterface;
 class BufferInterface;
-class ConfinedPointerInterface;
+class ConfinedPointerV1Interface;
 class ContrastInterface;
 class CompositorInterface;
-class LockedPointerInterface;
+class LockedPointerV1Interface;
 class ShadowInterface;
 class SlideInterface;
 class SubSurfaceInterface;
@@ -163,7 +163,6 @@ public:
     QRegion damage() const;
     QRegion opaque() const;
     QRegion input() const;
-    bool inputIsInfinite() const;
     qint32 bufferScale() const;
     /**
      * Returns the buffer transform that had been applied to the buffer to compensate for
@@ -203,11 +202,11 @@ public:
     /**
      * @returns The SubSurface for this Surface in case there is one.
      **/
-    QPointer<SubSurfaceInterface> subSurface() const;
+    SubSurfaceInterface *subSurface() const;
     /**
      * @returns Children in stacking order from bottom (first) to top (last).
      **/
-    QList<QPointer<SubSurfaceInterface>> childSubSurfaces() const;
+    QList<SubSurfaceInterface *> childSubSurfaces() const;
 
     /**
      * @returns The Shadow for this Surface.
@@ -324,14 +323,14 @@ public:
      * @see pointerConstraintsChanged
      * @since 5.29
      **/
-    QPointer<ConfinedPointerInterface> confinedPointer() const;
+    ConfinedPointerV1Interface *confinedPointer() const;
 
     /**
      * Pointer lock installed on this SurfaceInterface.
      * @see pointerConstraintsChanged
      * @since 5.29
      **/
-    QPointer<LockedPointerInterface> lockedPointer() const;
+    LockedPointerV1Interface *lockedPointer() const;
 
     /**
      * @returns Whether this SurfaceInterface wants idle to be inhibited on the Output it is shown
@@ -481,6 +480,8 @@ Q_SIGNALS:
     void committed();
 
 private:
+    void handleBufferRemoved(BufferInterface *buffer);
+
     QScopedPointer<SurfaceInterfacePrivate> d;
     friend class SurfaceInterfacePrivate;
 };
