@@ -170,7 +170,7 @@ void CompositorWindow::keyPressEvent(QKeyEvent *event)
         updateFocus();
     }
     m_seat->setTimestamp(event->timestamp());
-    m_seat->keyPressed(event->nativeScanCode() - 8);
+    m_seat->keyboard()->keyPressed(event->nativeScanCode() - 8);
 }
 
 void CompositorWindow::keyReleaseEvent(QKeyEvent *event)
@@ -180,7 +180,7 @@ void CompositorWindow::keyReleaseEvent(QKeyEvent *event)
         return;
     }
     m_seat->setTimestamp(event->timestamp());
-    m_seat->keyReleased(event->nativeScanCode() - 8);
+    m_seat->keyboard()->keyReleased(event->nativeScanCode() - 8);
 }
 
 void CompositorWindow::mouseMoveEvent(QMouseEvent *event)
@@ -239,17 +239,16 @@ int main(int argc, char **argv)
 
     Display display;
     display.start();
-    DataDeviceManagerInterface *ddm = display.createDataDeviceManager();
-    ddm->create();
-    display.createCompositor(&display);
-    XdgShellInterface *shell = display.createXdgShell();
+    new DataDeviceManagerInterface(&display);
+    new CompositorInterface(&display, &display);
+    XdgShellInterface *shell = new XdgShellInterface(&display);
     display.createShm();
-    OutputInterface *output = display.createOutput(&display);
+    OutputInterface *output = new OutputInterface(&display, &display);
     output->setPhysicalSize(QSize(269, 202));
     const QSize windowSize(1024, 768);
     output->addMode(windowSize);
     output->create();
-    SeatInterface *seat = display.createSeat();
+    SeatInterface *seat = new SeatInterface(&display);
     seat->setHasKeyboard(true);
     seat->setHasPointer(true);
     seat->setName(QStringLiteral("testSeat0"));
